@@ -86,7 +86,7 @@ class mdfSubset:
                         resampled = data[signals].interp(timesteps)
                         subsetListResampled.append(resampled)
                 elif data[signals].Type == 'Cont': # continous signals physical mesurement signals
-                        resampled = data[signals].interp(timesteps,interpolation_mode = '1') 
+                        resampled = data[signals].interp(timesteps,integer_interpolation_mode = '1') 
                         subsetListResampled.append(resampled)
             return mdfSubset(subsetListResampled,fname)
         
